@@ -49,8 +49,11 @@ __all__ = (
     "DocumentDefaultVersionDescriptionTypeDef",
     "DocumentDescriptionTypeDef",
     "DocumentIdentifierTypeDef",
+    "DocumentMetadataResponseInfoTypeDef",
     "DocumentParameterTypeDef",
     "DocumentRequiresTypeDef",
+    "DocumentReviewCommentSourceTypeDef",
+    "DocumentReviewerResponseSourceTypeDef",
     "DocumentVersionInfoTypeDef",
     "EffectivePatchTypeDef",
     "FailedCreateAssociationTypeDef",
@@ -92,6 +95,8 @@ __all__ = (
     "OpsEntityTypeDef",
     "OpsFilterTypeDef",
     "OpsItemDataValueTypeDef",
+    "OpsItemEventSummaryTypeDef",
+    "OpsItemIdentityTypeDef",
     "OpsItemNotificationTypeDef",
     "OpsItemSummaryTypeDef",
     "OpsItemTypeDef",
@@ -121,6 +126,8 @@ __all__ = (
     "ResourceDataSyncOrganizationalUnitTypeDef",
     "ResourceDataSyncS3DestinationTypeDef",
     "ResourceDataSyncSourceWithStateTypeDef",
+    "ReviewInformationTypeDef",
+    "RunbookTypeDef",
     "S3OutputLocationTypeDef",
     "S3OutputUrlTypeDef",
     "ScheduledWindowExecutionTypeDef",
@@ -193,6 +200,7 @@ __all__ = (
     "InventoryAggregatorTypeDef",
     "DocumentFilterTypeDef",
     "DocumentKeyValuesFilterTypeDef",
+    "DocumentReviewsTypeDef",
     "GetAutomationExecutionResultTypeDef",
     "GetCalendarStateResponseTypeDef",
     "GetCommandInvocationResultTypeDef",
@@ -228,14 +236,17 @@ __all__ = (
     "ListCommandsResultTypeDef",
     "ListComplianceItemsResultTypeDef",
     "ListComplianceSummariesResultTypeDef",
+    "ListDocumentMetadataHistoryResponseTypeDef",
     "ListDocumentVersionsResultTypeDef",
     "ListDocumentsResultTypeDef",
     "ListInventoryEntriesResultTypeDef",
+    "ListOpsItemEventsResponseTypeDef",
     "ListOpsMetadataResultTypeDef",
     "ListResourceComplianceSummariesResultTypeDef",
     "ListResourceDataSyncResultTypeDef",
     "ListTagsForResourceResultTypeDef",
     "MaintenanceWindowFilterTypeDef",
+    "OpsItemEventFilterTypeDef",
     "OpsItemFilterTypeDef",
     "OpsMetadataFilterTypeDef",
     "OpsResultAttributeTypeDef",
@@ -256,6 +267,7 @@ __all__ = (
     "SendCommandResultTypeDef",
     "SessionFilterTypeDef",
     "StartAutomationExecutionResultTypeDef",
+    "StartChangeRequestExecutionResultTypeDef",
     "StartSessionResponseTypeDef",
     "StepExecutionFilterTypeDef",
     "TerminateSessionResponseTypeDef",
@@ -317,6 +329,7 @@ AssociationDescriptionTypeDef = TypedDict(
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
         "SyncCompliance": Literal["AUTO", "MANUAL"],
         "ApplyOnlyAtCronInterval": bool,
+        "TargetLocations": List["TargetLocationTypeDef"],
     },
     total=False,
 )
@@ -408,6 +421,7 @@ AssociationVersionInfoTypeDef = TypedDict(
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
         "SyncCompliance": Literal["AUTO", "MANUAL"],
         "ApplyOnlyAtCronInterval": bool,
+        "TargetLocations": List["TargetLocationTypeDef"],
     },
     total=False,
 )
@@ -435,6 +449,16 @@ AutomationExecutionMetadataTypeDef = TypedDict(
             "Cancelling",
             "Cancelled",
             "Failed",
+            "PendingApproval",
+            "Approved",
+            "Rejected",
+            "Scheduled",
+            "RunbookInProgress",
+            "PendingChangeCalendarOverride",
+            "ChangeCalendarOverrideApproved",
+            "ChangeCalendarOverrideRejected",
+            "CompletedWithSuccess",
+            "CompletedWithFailure",
         ],
         "ExecutionStartTime": datetime,
         "ExecutionEndTime": datetime,
@@ -454,6 +478,12 @@ AutomationExecutionMetadataTypeDef = TypedDict(
         "MaxErrors": str,
         "Target": str,
         "AutomationType": Literal["CrossAccount", "Local"],
+        "AutomationSubtype": Literal["ChangeRequest"],
+        "ScheduledTime": datetime,
+        "Runbooks": List["RunbookTypeDef"],
+        "OpsItemId": str,
+        "AssociationId": str,
+        "ChangeRequestName": str,
     },
     total=False,
 )
@@ -475,6 +505,16 @@ AutomationExecutionTypeDef = TypedDict(
             "Cancelling",
             "Cancelled",
             "Failed",
+            "PendingApproval",
+            "Approved",
+            "Rejected",
+            "Scheduled",
+            "RunbookInProgress",
+            "PendingChangeCalendarOverride",
+            "ChangeCalendarOverrideApproved",
+            "ChangeCalendarOverrideRejected",
+            "CompletedWithSuccess",
+            "CompletedWithFailure",
         ],
         "StepExecutions": List["StepExecutionTypeDef"],
         "StepExecutionsTruncated": bool,
@@ -495,6 +535,12 @@ AutomationExecutionTypeDef = TypedDict(
         "Target": str,
         "TargetLocations": List["TargetLocationTypeDef"],
         "ProgressCounters": "ProgressCountersTypeDef",
+        "AutomationSubtype": Literal["ChangeRequest"],
+        "ScheduledTime": datetime,
+        "Runbooks": List["RunbookTypeDef"],
+        "OpsItemId": str,
+        "AssociationId": str,
+        "ChangeRequestName": str,
     },
     total=False,
 )
@@ -656,6 +702,7 @@ _OptionalCreateAssociationBatchRequestEntryTypeDef = TypedDict(
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
         "SyncCompliance": Literal["AUTO", "MANUAL"],
         "ApplyOnlyAtCronInterval": bool,
+        "TargetLocations": List["TargetLocationTypeDef"],
     },
     total=False,
 )
@@ -700,6 +747,7 @@ DocumentDescriptionTypeDef = TypedDict(
             "ApplicationConfigurationSchema",
             "DeploymentStrategy",
             "ChangeCalendar",
+            "Automation.ChangeTemplate",
         ],
         "SchemaVersion": str,
         "LatestVersion": str,
@@ -709,6 +757,11 @@ DocumentDescriptionTypeDef = TypedDict(
         "Tags": List["TagTypeDef"],
         "AttachmentsInformation": List["AttachmentInformationTypeDef"],
         "Requires": List["DocumentRequiresTypeDef"],
+        "Author": str,
+        "ReviewInformation": List["ReviewInformationTypeDef"],
+        "ApprovedVersion": str,
+        "PendingReviewVersion": str,
+        "ReviewStatus": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
     },
     total=False,
 )
@@ -731,16 +784,25 @@ DocumentIdentifierTypeDef = TypedDict(
             "ApplicationConfigurationSchema",
             "DeploymentStrategy",
             "ChangeCalendar",
+            "Automation.ChangeTemplate",
         ],
         "SchemaVersion": str,
         "DocumentFormat": Literal["YAML", "JSON", "TEXT"],
         "TargetType": str,
         "Tags": List["TagTypeDef"],
         "Requires": List["DocumentRequiresTypeDef"],
+        "ReviewStatus": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
+        "Author": str,
     },
     total=False,
 )
 
+DocumentMetadataResponseInfoTypeDef = TypedDict(
+    "DocumentMetadataResponseInfoTypeDef",
+    {"ReviewerResponse": List["DocumentReviewerResponseSourceTypeDef"]},
+    total=False,
+)
+
 DocumentParameterTypeDef = TypedDict(
     "DocumentParameterTypeDef",
     {"Name": str, "Type": Literal["String", "StringList"], "Description": str, "DefaultValue": str},
@@ -757,6 +819,22 @@ class DocumentRequiresTypeDef(_RequiredDocumentRequiresTypeDef, _OptionalDocumen
     pass
 
 
+DocumentReviewCommentSourceTypeDef = TypedDict(
+    "DocumentReviewCommentSourceTypeDef", {"Type": Literal["Comment"], "Content": str}, total=False
+)
+
+DocumentReviewerResponseSourceTypeDef = TypedDict(
+    "DocumentReviewerResponseSourceTypeDef",
+    {
+        "CreateTime": datetime,
+        "UpdatedTime": datetime,
+        "ReviewStatus": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
+        "Comment": List["DocumentReviewCommentSourceTypeDef"],
+        "Reviewer": str,
+    },
+    total=False,
+)
+
 DocumentVersionInfoTypeDef = TypedDict(
     "DocumentVersionInfoTypeDef",
     {
@@ -768,6 +846,7 @@ DocumentVersionInfoTypeDef = TypedDict(
         "DocumentFormat": Literal["YAML", "JSON", "TEXT"],
         "Status": Literal["Creating", "Active", "Updating", "Deleting", "Failed"],
         "StatusInformation": str,
+        "ReviewStatus": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
     },
     total=False,
 )
@@ -1227,6 +1306,22 @@ OpsItemDataValueTypeDef = TypedDict(
     total=False,
 )
 
+OpsItemEventSummaryTypeDef = TypedDict(
+    "OpsItemEventSummaryTypeDef",
+    {
+        "OpsItemId": str,
+        "EventId": str,
+        "Source": str,
+        "DetailType": str,
+        "Detail": str,
+        "CreatedBy": "OpsItemIdentityTypeDef",
+        "CreatedTime": datetime,
+    },
+    total=False,
+)
+
+OpsItemIdentityTypeDef = TypedDict("OpsItemIdentityTypeDef", {"Arn": str}, total=False)
+
 OpsItemNotificationTypeDef = TypedDict("OpsItemNotificationTypeDef", {"Arn": str}, total=False)
 
 OpsItemSummaryTypeDef = TypedDict(
@@ -1238,12 +1333,36 @@ OpsItemSummaryTypeDef = TypedDict(
         "LastModifiedTime": datetime,
         "Priority": int,
         "Source": str,
-        "Status": Literal["Open", "InProgress", "Resolved"],
+        "Status": Literal[
+            "Open",
+            "InProgress",
+            "Resolved",
+            "Pending",
+            "TimedOut",
+            "Cancelling",
+            "Cancelled",
+            "Failed",
+            "CompletedWithSuccess",
+            "CompletedWithFailure",
+            "Scheduled",
+            "RunbookInProgress",
+            "PendingChangeCalendarOverride",
+            "ChangeCalendarOverrideApproved",
+            "ChangeCalendarOverrideRejected",
+            "PendingApproval",
+            "Approved",
+            "Rejected",
+        ],
         "OpsItemId": str,
         "Title": str,
         "OperationalData": Dict[str, "OpsItemDataValueTypeDef"],
         "Category": str,
         "Severity": str,
+        "OpsItemType": str,
+        "ActualStartTime": datetime,
+        "ActualEndTime": datetime,
+        "PlannedStartTime": datetime,
+        "PlannedEndTime": datetime,
     },
     total=False,
 )
@@ -1252,6 +1371,7 @@ OpsItemTypeDef = TypedDict(
     "OpsItemTypeDef",
     {
         "CreatedBy": str,
+        "OpsItemType": str,
         "CreatedTime": datetime,
         "Description": str,
         "LastModifiedBy": str,
@@ -1259,7 +1379,26 @@ OpsItemTypeDef = TypedDict(
         "Notifications": List["OpsItemNotificationTypeDef"],
         "Priority": int,
         "RelatedOpsItems": List["RelatedOpsItemTypeDef"],
-        "Status": Literal["Open", "InProgress", "Resolved"],
+        "Status": Literal[
+            "Open",
+            "InProgress",
+            "Resolved",
+            "Pending",
+            "TimedOut",
+            "Cancelling",
+            "Cancelled",
+            "Failed",
+            "CompletedWithSuccess",
+            "CompletedWithFailure",
+            "Scheduled",
+            "RunbookInProgress",
+            "PendingChangeCalendarOverride",
+            "ChangeCalendarOverrideApproved",
+            "ChangeCalendarOverrideRejected",
+            "PendingApproval",
+            "Approved",
+            "Rejected",
+        ],
         "OpsItemId": str,
         "Version": str,
         "Title": str,
@@ -1267,6 +1406,10 @@ OpsItemTypeDef = TypedDict(
         "OperationalData": Dict[str, "OpsItemDataValueTypeDef"],
         "Category": str,
         "Severity": str,
+        "ActualStartTime": datetime,
+        "ActualEndTime": datetime,
+        "PlannedStartTime": datetime,
+        "PlannedEndTime": datetime,
     },
     total=False,
 )
@@ -1621,6 +1764,36 @@ ResourceDataSyncSourceWithStateTypeDef = TypedDict(
     total=False,
 )
 
+ReviewInformationTypeDef = TypedDict(
+    "ReviewInformationTypeDef",
+    {
+        "ReviewedTime": datetime,
+        "Status": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
+        "Reviewer": str,
+    },
+    total=False,
+)
+
+_RequiredRunbookTypeDef = TypedDict("_RequiredRunbookTypeDef", {"DocumentName": str})
+_OptionalRunbookTypeDef = TypedDict(
+    "_OptionalRunbookTypeDef",
+    {
+        "DocumentVersion": str,
+        "Parameters": Dict[str, List[str]],
+        "TargetParameterName": str,
+        "Targets": List["TargetTypeDef"],
+        "MaxConcurrency": str,
+        "MaxErrors": str,
+        "TargetLocations": List["TargetLocationTypeDef"],
+    },
+    total=False,
+)
+
+
+class RunbookTypeDef(_RequiredRunbookTypeDef, _OptionalRunbookTypeDef):
+    pass
+
+
 S3OutputLocationTypeDef = TypedDict(
     "S3OutputLocationTypeDef",
     {"OutputS3Region": str, "OutputS3BucketName": str, "OutputS3KeyPrefix": str},
@@ -1702,6 +1875,16 @@ StepExecutionTypeDef = TypedDict(
             "Cancelling",
             "Cancelled",
             "Failed",
+            "PendingApproval",
+            "Approved",
+            "Rejected",
+            "Scheduled",
+            "RunbookInProgress",
+            "PendingChangeCalendarOverride",
+            "ChangeCalendarOverrideApproved",
+            "ChangeCalendarOverrideRejected",
+            "CompletedWithSuccess",
+            "CompletedWithFailure",
         ],
         "ResponseCode": str,
         "Inputs": Dict[str, str],
@@ -1792,6 +1975,8 @@ AutomationExecutionFilterTypeDef = TypedDict(
             "AutomationType",
             "TagKey",
             "TargetResourceGroup",
+            "AutomationSubtype",
+            "OpsItemId",
         ],
         "Values": List[str],
     },
@@ -2173,6 +2358,21 @@ DocumentKeyValuesFilterTypeDef = TypedDict(
     "DocumentKeyValuesFilterTypeDef", {"Key": str, "Values": List[str]}, total=False
 )
 
+_RequiredDocumentReviewsTypeDef = TypedDict(
+    "_RequiredDocumentReviewsTypeDef",
+    {"Action": Literal["SendForReview", "UpdateReview", "Approve", "Reject"]},
+)
+_OptionalDocumentReviewsTypeDef = TypedDict(
+    "_OptionalDocumentReviewsTypeDef",
+    {"Comment": List["DocumentReviewCommentSourceTypeDef"]},
+    total=False,
+)
+
+
+class DocumentReviewsTypeDef(_RequiredDocumentReviewsTypeDef, _OptionalDocumentReviewsTypeDef):
+    pass
+
+
 GetAutomationExecutionResultTypeDef = TypedDict(
     "GetAutomationExecutionResultTypeDef",
     {"AutomationExecution": "AutomationExecutionTypeDef"},
@@ -2269,10 +2469,12 @@ GetDocumentResultTypeDef = TypedDict(
             "ApplicationConfigurationSchema",
             "DeploymentStrategy",
             "ChangeCalendar",
+            "Automation.ChangeTemplate",
         ],
         "DocumentFormat": Literal["YAML", "JSON", "TEXT"],
         "Requires": List["DocumentRequiresTypeDef"],
         "AttachmentsContent": List["AttachmentContentTypeDef"],
+        "ReviewStatus": Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"],
     },
     total=False,
 )
@@ -2593,6 +2795,18 @@ ListComplianceSummariesResultTypeDef = TypedDict(
     total=False,
 )
 
+ListDocumentMetadataHistoryResponseTypeDef = TypedDict(
+    "ListDocumentMetadataHistoryResponseTypeDef",
+    {
+        "Name": str,
+        "DocumentVersion": str,
+        "Author": str,
+        "Metadata": "DocumentMetadataResponseInfoTypeDef",
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListDocumentVersionsResultTypeDef = TypedDict(
     "ListDocumentVersionsResultTypeDef",
     {"DocumentVersions": List["DocumentVersionInfoTypeDef"], "NextToken": str},
@@ -2618,6 +2832,12 @@ ListInventoryEntriesResultTypeDef = TypedDict(
     total=False,
 )
 
+ListOpsItemEventsResponseTypeDef = TypedDict(
+    "ListOpsItemEventsResponseTypeDef",
+    {"NextToken": str, "Summaries": List["OpsItemEventSummaryTypeDef"]},
+    total=False,
+)
+
 ListOpsMetadataResultTypeDef = TypedDict(
     "ListOpsMetadataResultTypeDef",
     {"OpsMetadataList": List["OpsMetadataTypeDef"], "NextToken": str},
@@ -2647,6 +2867,11 @@ MaintenanceWindowFilterTypeDef = TypedDict(
     "MaintenanceWindowFilterTypeDef", {"Key": str, "Values": List[str]}, total=False
 )
 
+OpsItemEventFilterTypeDef = TypedDict(
+    "OpsItemEventFilterTypeDef",
+    {"Key": Literal["OpsItemId"], "Values": List[str], "Operator": Literal["Equal"]},
+)
+
 OpsItemFilterTypeDef = TypedDict(
     "OpsItemFilterTypeDef",
     {
@@ -2659,6 +2884,10 @@ OpsItemFilterTypeDef = TypedDict(
             "OpsItemId",
             "CreatedTime",
             "LastModifiedTime",
+            "ActualStartTime",
+            "ActualEndTime",
+            "PlannedStartTime",
+            "PlannedEndTime",
             "OperationalData",
             "OperationalDataKey",
             "OperationalDataValue",
@@ -2666,6 +2895,13 @@ OpsItemFilterTypeDef = TypedDict(
             "AutomationId",
             "Category",
             "Severity",
+            "OpsItemType",
+            "ChangeRequestByRequesterArn",
+            "ChangeRequestByRequesterName",
+            "ChangeRequestByApproverArn",
+            "ChangeRequestByApproverName",
+            "ChangeRequestByTemplate",
+            "ChangeRequestByTargetsResourceGroup",
         ],
         "Values": List[str],
         "Operator": Literal["Equal", "Contains", "GreaterThan", "LessThan"],
@@ -2775,6 +3011,10 @@ StartAutomationExecutionResultTypeDef = TypedDict(
     "StartAutomationExecutionResultTypeDef", {"AutomationExecutionId": str}, total=False
 )
 
+StartChangeRequestExecutionResultTypeDef = TypedDict(
+    "StartChangeRequestExecutionResultTypeDef", {"AutomationExecutionId": str}, total=False
+)
+
 StartSessionResponseTypeDef = TypedDict(
     "StartSessionResponseTypeDef",
     {"SessionId": str, "TokenValue": str, "StreamUrl": str},
